==> haskell-hspec-contrib-0.5.2-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-I6EOYsc6DIaDZTX1xqtdlE
key:                  hspec-contrib-0.5.2-I6EOYsc6DIaDZTX1xqtdlE
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  967b95a30d3c4e4c602d6e26c15df90c
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-I6EOYsc6DIaDZTX1xqtdlE
depends:
    HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA base-4.17.2.1
    call-stack-0.4.0-GLZYnk9HL8J8EgKDjlcntK
    hspec-core-2.11.0-81xu7oQKWO3LLNddi7Yvwr

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.2-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-FAoCD9lIsKPDymJ7ca24dv
key:                  hspec-contrib-0.5.2-FAoCD9lIsKPDymJ7ca24dv
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  03c9107f175c8b15f91efb277b3c5b8b
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-FAoCD9lIsKPDymJ7ca24dv
depends:
    HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA base-4.17.2.1
    call-stack-0.4.0-GLZYnk9HL8J8EgKDjlcntK
    hspec-core-2.11.0-LPTvMr9J8dgGLMgUW1MuAl

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
